package com.kmall.schedule.dao;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @author huangyq
 * @date 2019/5/5.
 */
@Component
public interface QzStorePromMapper {

    /**
     * 查询渠道推广数据
     * @return
     */
    List<Map> queryStorePromList();

    /**
     * 查询未开始的推广数据
     * @return
     */
    List<Map> queryStorePromByNotStartList();
    /**
     * 更新过期时间
     * @param fromObject
     */
    void updateStoreProm(Map fromObject);

    /**
     * 查询支付成功或退款成功的渠道推广订单
     * @return
     */
    List<Map> queryStorePromByPaySuccess(@Param("statusList")Integer[] statusList);

    /**
     * 更新统计数据
     *
     * @return
     */
    int updateStorePromStat(Map params);

    /**
     * 统计推广订单的支付单数,支付人数,应收金额,支付件数,订单实付金额
     * @param goodsId
     * @return
     */
    Map getStatDataByGoodsId(@Param("goodsId") Integer goodsId, @Param("statusList")Integer[] statusList);

    /**
     * 查询订单详情中排除不属于渠道的总金额
     * @param map
     * @return
     */
    Map getActMoneyDataByGoodsId(Map map);

    List<Map> getStoreRealByGoodsIdList(@Param("goodsId") Integer goodsId, @Param("statusList")Integer[] statusList);

    /**
     * 更新渠道数据扫描状态
     * @param params
     */
    void updatePromRealIsPromScan(Map params);
}
